==> kvision-common-annotations-js-5.3.0.jar: kvision-kvision-common-annotations-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-common-annotations-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-common-annotations-js-legacy'.");
    }root['kvision-kvision-common-annotations-js-legacy'] = factory(typeof this['kvision-kvision-common-annotations-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-common-annotations-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Enum = Kotlin.kotlin.Enum;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var throwISE = Kotlin.throwISE;
  var Annotation = Kotlin.kotlin.Annotation;
  Method.prototype = Object.create(Enum.prototype);
  Method.prototype.constructor = Method;
  function Method(name, ordinal) {
    Enum.call(this);
    this.name$ = name;
    this.ordinal$ = ordinal;
  }
  function Method_initFields() {
    Method_initFields = function () {
    };
    Method$GET_instance = new Method('GET', 0);
    Method$POST_instance = new Method('POST', 1);
    Method$PUT_instance = new Method('PUT', 2);
    Method$DELETE_instance = new Method('DELETE', 3);
    Method$OPTIONS_instance = new Method('OPTIONS', 4);
  }
  var Method$GET_instance;
  function Method$GET_getInstance() {
    Method_initFields();
    return Method$GET_instance;
  }
  var Method$POST_instance;
  function Method$POST_getInstance() {
    Method_initFields();
    return Method$POST_instance;
  }
  var Method$PUT_instance;
  function Method$PUT_getInstance() {
    Method_initFields();
    return Method$PUT_instance;
  }
  var Method$DELETE_instance;
  function Method$DELETE_getInstance() {
    Method_initFields();
    return Method$DELETE_instance;
  }
  var Method$OPTIONS_instance;
  function Method$OPTIONS_getInstance() {
    Method_initFields();
    return Method$OPTIONS_instance;
  }
  Method.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Method',
    interfaces: [Enum]
  };
  function Method$values() {
    return [Method$GET_getInstance(), Method$POST_getInstance(), Method$PUT_getInstance(), Method$DELETE_getInstance(), Method$OPTIONS_getInstance()];
  }
  Method.values = Method$values;
  function Method$valueOf(name) {
    switch (name) {
      case 'GET':
        return Method$GET_getInstance();
      case 'POST':
        return Method$POST_getInstance();
      case 'PUT':
        return Method$PUT_getInstance();
      case 'DELETE':
        return Method$DELETE_getInstance();
      case 'OPTIONS':
        return Method$OPTIONS_getInstance();
      default:throwISE('No enum constant io.kvision.annotations.Method.' + name);
    }
  }
  Method.valueOf_61zpoe$ = Method$valueOf;
  function KVService() {
  }
  KVService.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVService',
    interfaces: [Annotation]
  };
  function KVBinding(method, route) {
    this.method = method;
    this.route = route;
  }
  KVBinding.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVBinding',
    interfaces: [Annotation]
  };
  function KVBindingMethod(method) {
    this.method = method;
  }
  KVBindingMethod.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVBindingMethod',
    interfaces: [Annotation]
  };
  function KVBindingRoute(route) {
    this.route = route;
  }
  KVBindingRoute.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVBindingRoute',
    interfaces: [Annotation]
  };
  Object.defineProperty(Method, 'GET', {
    get: Method$GET_getInstance
  });
  Object.defineProperty(Method, 'POST', {
    get: Method$POST_getInstance
  });
  Object.defineProperty(Method, 'PUT', {
    get: Method$PUT_getInstance
  });
  Object.defineProperty(Method, 'DELETE', {
    get: Method$DELETE_getInstance
  });
  Object.defineProperty(Method, 'OPTIONS', {
    get: Method$OPTIONS_getInstance
  });
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$annotations = package$kvision.annotations || (package$kvision.annotations = {});
  package$annotations.Method = Method;
  package$annotations.KVService = KVService;
  package$annotations.KVBinding = KVBinding;
  package$annotations.KVBindingMethod = KVBindingMethod;
  package$annotations.KVBindingRoute = KVBindingRoute;
  Kotlin.defineModule('kvision-kvision-common-annotations-js-legacy', _);
  return _;
}));

==> kvision-common-annotations-js-5.15.0.jar: kvision-kvision-common-annotations-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-common-annotations-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-common-annotations-js-legacy'.");
    }
    root['kvision-kvision-common-annotations-js-legacy'] = factory(typeof this['kvision-kvision-common-annotations-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-common-annotations-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Enum = Kotlin.kotlin.Enum;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var throwISE = Kotlin.throwISE;
  var Annotation = Kotlin.kotlin.Annotation;
  Method.prototype = Object.create(Enum.prototype);
  Method.prototype.constructor = Method;
  function Method(name, ordinal) {
    Enum.call(this);
    this.name$ = name;
    this.ordinal$ = ordinal;
  }
  function Method_initFields() {
    Method_initFields = function () {
    };
    Method$GET_instance = new Method('GET', 0);
    Method$POST_instance = new Method('POST', 1);
    Method$PUT_instance = new Method('PUT', 2);
    Method$DELETE_instance = new Method('DELETE', 3);
    Method$OPTIONS_instance = new Method('OPTIONS', 4);
  }
  var Method$GET_instance;
  function Method$GET_getInstance() {
    Method_initFields();
    return Method$GET_instance;
  }
  var Method$POST_instance;
  function Method$POST_getInstance() {
    Method_initFields();
    return Method$POST_instance;
  }
  var Method$PUT_instance;
  function Method$PUT_getInstance() {
    Method_initFields();
    return Method$PUT_instance;
  }
  var Method$DELETE_instance;
  function Method$DELETE_getInstance() {
    Method_initFields();
    return Method$DELETE_instance;
  }
  var Method$OPTIONS_instance;
  function Method$OPTIONS_getInstance() {
    Method_initFields();
    return Method$OPTIONS_instance;
  }
  Method.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Method',
    interfaces: [Enum]
  };
  function Method$values() {
    return [Method$GET_getInstance(), Method$POST_getInstance(), Method$PUT_getInstance(), Method$DELETE_getInstance(), Method$OPTIONS_getInstance()];
  }
  Method.values = Method$values;
  function Method$valueOf(name) {
    switch (name) {
      case 'GET':
        return Method$GET_getInstance();
      case 'POST':
        return Method$POST_getInstance();
      case 'PUT':
        return Method$PUT_getInstance();
      case 'DELETE':
        return Method$DELETE_getInstance();
      case 'OPTIONS':
        return Method$OPTIONS_getInstance();
      default:
        throwISE('No enum constant io.kvision.annotations.Method.' + name);
    }
  }
  Method.valueOf_61zpoe$ = Method$valueOf;
  function KVService() {
  }
  KVService.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVService',
    interfaces: [Annotation]
  };
  function KVBinding(method, route) {
    this.method = method;
    this.route = route;
  }
  KVBinding.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVBinding',
    interfaces: [Annotation]
  };
  function KVBindingMethod(method) {
    this.method = method;
  }
  KVBindingMethod.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVBindingMethod',
    interfaces: [Annotation]
  };
  function KVBindingRoute(route) {
    this.route = route;
  }
  KVBindingRoute.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVBindingRoute',
    interfaces: [Annotation]
  };
  Object.defineProperty(Method, 'GET', {
    get: Method$GET_getInstance
  });
  Object.defineProperty(Method, 'POST', {
    get: Method$POST_getInstance
  });
  Object.defineProperty(Method, 'PUT', {
    get: Method$PUT_getInstance
  });
  Object.defineProperty(Method, 'DELETE', {
    get: Method$DELETE_getInstance
  });
  Object.defineProperty(Method, 'OPTIONS', {
    get: Method$OPTIONS_getInstance
  });
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$annotations = package$kvision.annotations || (package$kvision.annotations = {});
  package$annotations.Method = Method;
  package$annotations.KVService = KVService;
  package$annotations.KVBinding = KVBinding;
  package$annotations.KVBindingMethod = KVBindingMethod;
  package$annotations.KVBindingRoute = KVBindingRoute;
  Kotlin.defineModule('kvision-kvision-common-annotations-js-legacy', _);
  return _;
}));
